# Flumel

[![Intégration continue](https://gitlab.com/canarduck/flumel/badges/master/pipeline.svg)](https://gitlab.com/canarduck/flumel/commits/master) [![Couverture des tests](https://gitlab.com/canarduck/flumel/badges/master/coverage.svg)](https://canarduck.gitlab.io/flumel/) [![Documentation](https://readthedocs.org/projects/flumel/badge/?version=latest)](https://flumel.readthedocs.io/fr/latest/)

Encore un moyen de recevoir ses flux RSS par email

* Documentation : https://flumel.readthedocs.io/fr/latest/
* Dépôt : https://gitlab.com/canarduck/flumel